@@ -12,6 +12,7 @@ mod cntp_ctl_el0;
 mod cntp_tval_el0;
 mod cntpct_el0;
 mod cntv_ctl_el0;
+mod cntv_cval_el0;
 mod cntv_tval_el0;
 mod cntvct_el0;
 mod cntvoff_el2;
@@ -32,6 +33,7 @@ mod mair_el1;
 mod mair_el2;
 mod midr_el1;
 mod mpidr_el1;
+mod oslar_el1;
 mod par_el1;
 mod scr_el3;
 mod sctlr_el1;
@@ -52,6 +54,7 @@ mod ttbr0_el1;
 mod ttbr0_el2;
 mod ttbr1_el1;
 mod vbar_el1;
+mod vbar_el2;
 
 pub use cntfrq_el0::CNTFRQ_EL0;
 pub use cnthctl_el2::CNTHCTL_EL2;
@@ -59,6 +62,7 @@ pub use cntp_ctl_el0::CNTP_CTL_EL0;
 pub use cntp_tval_el0::CNTP_TVAL_EL0;
 pub use cntpct_el0::CNTPCT_EL0;
 pub use cntv_ctl_el0::CNTV_CTL_EL0;
+pub use cntv_cval_el0::CNTV_CVAL_EL0;
 pub use cntv_tval_el0::CNTV_TVAL_EL0;
 pub use cntvct_el0::CNTVCT_EL0;
 pub use cntvoff_el2::CNTVOFF_EL2;
@@ -79,6 +83,7 @@ pub use mair_el1::MAIR_EL1;
 pub use mair_el2::MAIR_EL2;
 pub use midr_el1::MIDR_EL1;
 pub use mpidr_el1::MPIDR_EL1;
+pub use oslar_el1::OSLAR_EL1;
 pub use par_el1::PAR_EL1;
 pub use scr_el3::SCR_EL3;
 pub use sctlr_el1::SCTLR_EL1;
@@ -99,3 +104,4 @@ pub use ttbr0_el1::TTBR0_EL1;
 pub use ttbr0_el2::TTBR0_EL2;
 pub use ttbr1_el1::TTBR1_EL1;
 pub use vbar_el1::VBAR_EL1;
+pub use vbar_el2::VBAR_EL2;
